aboutsummaryrefslogtreecommitdiffstats
path: root/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c
diff options
context:
space:
mode:
Diffstat (limited to 'Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c')
-rw-r--r--Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c b/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c
index 9a7ff4725..7091e8643 100644
--- a/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c
+++ b/Demos/Device/ClassDriver/DualVirtualSerial/DualVirtualSerial.c
@@ -1,13 +1,13 @@
/*
LUFA Library
- Copyright (C) Dean Camera, 2017.
+ Copyright (C) Dean Camera, 2019.
dean [at] fourwalledcubicle [dot] com
www.lufa-lib.org
*/
/*
- Copyright 2017 Dean Camera (dean [at] fourwalledcubicle [dot] com)
+ Copyright 2019 Dean Camera (dean [at] fourwalledcubicle [dot] com)
Permission to use, copy, modify, distribute, and sell this
software and its documentation for any purpose is hereby granted
@@ -231,12 +231,14 @@ void EVENT_CDC_Device_ControLineStateChanged(USB_ClassInfo_CDC_Device_t *const C
*/
bool HostReady = (CDCInterfaceInfo->State.ControlLineStates.HostToDevice & CDC_CONTROL_LINE_OUT_DTR) != 0;
+ (void)HostReady;
+
if (CDCInterfaceInfo == &VirtualSerial1_CDC_Interface)
{
// CDC interface 1's host is ready to send/receive data
}
else
{
// CDC interface 2's host is ready to send/receive data
}
}
@@ -231,12 +231,14 @@ void EVENT_CDC_Device_ControLineStateChanged(USB_ClassInfo_CDC_Device_t *const C
if (CDCInterfaceInfo == &VirtualSerial1_CDC_Interface)
{
- // CDC interface 1's host is ready to send/receive data
+ // CDC interface 1's host is ready to send/receive data if HostReady is true
}
else
@@ -231,12 +231,14 @@ void EVENT_CDC_Device_ControLineStateChanged(USB_ClassInfo_CDC_Device_t *const C
else
{
- // CDC interface 2's host is ready to send/receive data
+ // CDC interface 2's host is ready to send/receive data if HostReady is true
}
}